@@ -5,8 +5,7 @@
 #' @param status A single character indicating the current XO-status.
 #' @param boxsize A single numeric value, indicating the boxsize to be considered.
 #' @param log TRUE, if logarithmic scales should be used.
-#' @param offset A numeric value 
-nextBox <- function(quote,status, boxsize=1, log=FALSE, offset=0) {
+nextBox <- function(quote,status, boxsize=1, log=FALSE) {
   if (!(is.numeric(quote))) {
     stop("Argument quote has to be numeric!")
   }
@@ -19,12 +18,13 @@ nextBox <- function(quote,status, boxsize=1, log=FALSE, offset=0) {
   if(!(is.logical(log) & length(log))) {
     stop("Argument log has to be logical and of length 1!")
   }
-  if (!(is.numeric(offset) & length(offset)==1)) {
-    stop("Argument offset has to be numeric and of length 1!")
+
+  if (status == "X") {
+    return(scaleToQuote((quoteToBoxnumber(quote,status,boxsize,log)+1)*boxsize,log))
+  } else if (status == "O") {
+    return(scaleToQuote((quoteToBoxnumber(quote,status,boxsize,log)-1)*boxsize,log))
+  } else {
+    stop(paste0("Unknown X/O-status ",status,"observed!"))
   }
-  
-  if (status == "X")
-    box2upper(quote2box(quote=quote,boxsize=boxsize,log=log)+offset,boxsize=boxsize,log=log)
-  else 
-    box2lower(quote2box(quote=quote,boxsize=boxsize,log=log)+offset,boxsize=boxsize,log=log)
 }
+
