@@ -4,15 +4,19 @@
 #' @param reversal number of boxes needed to make a reversal 
 #' @param boxsize A single numeric value, indicating the boxsize to be considered.
 #' @param log TRUE, if logarithmic scales should be used.
-nextReversal <- function(quote,status, reversal=3L, boxsize=1, log=FALSE) {
+nextReversal <- function(quote, status, reversal=3L, boxsize=1, log=FALSE) {
   if (!(is.numeric(quote))) {
     stop("Argument quote has to be numeric!")
   }
   if (!(is.character(status) & nchar(status)==1)) {
     stop("Argument status has to be a character and of length 1!")
   }
-  if (status == "X")
-    return (nextBox(quote, "O", boxsize=boxsize,log=log, offset=-reversal+1))
-  else
-    return (nextBox(quote, "X", boxsize=boxsize,log=log, offset=reversal-1))
+  
+  if (status == "X") {
+    return(scaleToQuote((quoteToBoxnumber(quote,status,boxsize,log)-reversal)*boxsize,log))
+  } else if (status == "O") {
+    return(scaleToQuote((quoteToBoxnumber(quote,status,boxsize,log)+reversal)*boxsize,log))
+  } else {
+    stop(paste0("Unknown X/O-status ",status,"observed!"))
+  }
 }
